pub enum CrcError {
Build(BuilderError),
BufferTooSmall {
required: usize,
provided: usize,
},
ValidationFailed {
expected: u16,
calculated: u16,
},
DataField(DataFieldError),
}Expand description
An error related to CRC operations.
Variants
Build(BuilderError)
An error occurred during the underlying packet build.
BufferTooSmall
The buffer was too small to hold the packet and its CRC.
ValidationFailed
The calculated CRC did not match the one in the buffer.
Fields
DataField(DataFieldError)
An error occurred parsing the underlying data field.