decode

Function decode 

pub fn decode(codeword: &mut [u8; 255]) -> Result<usize, RsError>
Decodes and corrects a 255-byte RS codeword in-place.

Returns the number of corrected symbol errors, or an error if there are too many to correct (>16).