CaduError

Enum CaduError 

pub enum CaduError {
    BufferTooSmall {
        required: usize,
        provided: usize,
    },
    InputTooShort,
    AsmMismatch,
}
Errors that can occur during CADU operations.

Variants



BufferTooSmall

The output buffer is too small for the CADU.

Fields

required: usize

Minimum number of bytes needed.

provided: usize

Actual buffer size provided.



InputTooShort

The input is too short to contain an ASM and frame.



AsmMismatch

The expected ASM was not found at the start of the data.