encoded_cltu_len

Function encoded_cltu_len 

pub fn encoded_cltu_len(tc_frame_len: usize) -> usize
Computes the required buffer size for encoding a TC frame of a given length into a CLTU.

This is a helper function to allow users to allocate a correctly-sized buffer before calling encode_cltu.