PushError

Enum PushError 

pub enum PushError {
    Full,
    TooLarge,
}
Push failed: the frame cannot accept this packet.

Variants



Full

The current frame is full but the packet would fit after a flush.



TooLarge

The packet exceeds the maximum data field length and can never fit in any frame.