ControlFlag

Enum ControlFlag 

#[repr(u8)]
pub enum ControlFlag { TypeD = 0, TypeC = 1, }
The Control Command Flag, indicating whether the frame contains user data or control information for the receiver.

Variants



TypeD = 0

The frame contains user data (e.g., a SpacePacket).



TypeC = 1

The frame contains control information (Type-C).