pub struct TelecommandTransferFrameHeader { /* private fields */ }Expand description
The 5-byte header of a Telecommand Transfer Frame.
Implementations
Sourceimpl TelecommandTransferFrameHeader
impl TelecommandTransferFrameHeader
Sourcepub fn frame_len(&self) -> usize
pub fn frame_len(&self) -> usize
Returns the total frame length in bytes as specified by the header.
Sourcepub fn set_frame_len(&mut self, length: usize)
pub fn set_frame_len(&mut self, length: usize)
Sets the total frame length in bytes as stored in the header.
Sourcepub fn sequence_num(&self) -> u8
pub fn sequence_num(&self) -> u8
Returns the Frame Sequence Number.
Sourcepub fn set_sequence_num(&mut self, seq: u8)
pub fn set_sequence_num(&mut self, seq: u8)
Sets the Frame Sequence Number.
Sourcepub fn bypass_flag(&self) -> BypassFlag
pub fn bypass_flag(&self) -> BypassFlag
Returns the Bypass Flag.
Sourcepub fn set_bypass_flag(&mut self, flag: BypassFlag)
pub fn set_bypass_flag(&mut self, flag: BypassFlag)
Sets the Bypass Flag.
Sourcepub fn control_flag(&self) -> ControlFlag
pub fn control_flag(&self) -> ControlFlag
Returns the Control Command Flag.
Sourcepub fn set_control_flag(&mut self, flag: ControlFlag)
pub fn set_control_flag(&mut self, flag: ControlFlag)
Sets the Control Command Flag.