AsymmetricLink

Struct AsymmetricLink 

pub struct AsymmetricLink<S, R> { /* private fields */ }
A data link composed of separate sender and receiver halves.

Implementations

Source

impl<S, R> AsymmetricLink<S, R>

pub fn new(sender: S, receiver: R) -> Self

Creates a new asymmetric link from separate sender and receiver.