pub struct SecurityHeader<'a> { /* private fields */ }Expand description
A parsed view over a Security Header in a byte buffer.
The Security Header consists of:
- SPI (16 bits, mandatory)
- Initialization Vector (0-32 bytes, optional)
- Sequence Number (0-8 bytes, optional)
- Pad Length (0-2 bytes, optional)
All field lengths are determined by the Security Association.
Implementations
Sourceimpl<'a> SecurityHeader<'a>
impl<'a> SecurityHeader<'a>
Sourcepub fn parse(sa: &SecurityAssociation, bytes: &'a [u8]) -> Result<Self, Error>
pub fn parse(sa: &SecurityAssociation, bytes: &'a [u8]) -> Result<Self, Error>
Parse a Security Header from the given bytes using the SA to determine field lengths.
Sourcepub fn sequence_number(&self) -> &[u8] ⓘ
pub fn sequence_number(&self) -> &[u8] ⓘ
Returns the Sequence Number bytes.
Sourcepub fn sequence_number_value(&self) -> u64
pub fn sequence_number_value(&self) -> u64
Returns the Sequence Number as a u64 value.
Sourcepub fn pad_length(&self) -> u16
pub fn pad_length(&self) -> u16
Returns the Pad Length value.