pub struct EncapsulationHeader { /* private fields */ }Expand description
The 2-byte mandatory portion of an Encapsulation Packet header.
Implementations
Sourceimpl EncapsulationHeader
impl EncapsulationHeader
Sourcepub fn protocol_id(&self) -> u8
pub fn protocol_id(&self) -> u8
Returns the 4-bit Protocol ID.
Sourcepub fn set_protocol_id(&mut self, pid: u8)
pub fn set_protocol_id(&mut self, pid: u8)
Sets the 4-bit Protocol ID.
Sourcepub fn len_of_len(&self) -> u8
pub fn len_of_len(&self) -> u8
Returns the 2-bit Length of Length field.
This determines how many bytes follow for the packet length:
- 0b00: 0 bytes (length is implicit/undefined)
- 0b01: 1 byte (max 255)
- 0b10: 2 bytes (max 65535)
- 0b11: 4 bytes (max 4294967295)
Sourcepub fn set_len_of_len(&mut self, lol: u8)
pub fn set_len_of_len(&mut self, lol: u8)
Sets the 2-bit Length of Length field.
Sourcepub fn user_defined(&self) -> u8
pub fn user_defined(&self) -> u8
Returns the 4-bit User Defined field.
Sourcepub fn set_user_defined(&mut self, ud: u8)
pub fn set_user_defined(&mut self, ud: u8)
Sets the 4-bit User Defined field.
Sourcepub fn protocol_id_extension(&self) -> u8
pub fn protocol_id_extension(&self) -> u8
Returns the 4-bit Protocol ID Extension.
Sourcepub fn set_protocol_id_extension(&mut self, ext: u8)
pub fn set_protocol_id_extension(&mut self, ext: u8)
Sets the 4-bit Protocol ID Extension.
Sourcepub fn ccsds_defined(&self) -> bool
pub fn ccsds_defined(&self) -> bool
Returns the 1-bit CCSDS Defined field.
Sourcepub fn set_ccsds_defined(&mut self, val: bool)
pub fn set_ccsds_defined(&mut self, val: bool)
Sets the 1-bit CCSDS Defined field.
Sourcepub fn packet_length_bytes(&self) -> usize
pub fn packet_length_bytes(&self) -> usize
Returns the number of bytes used for the packet length field.
Sourcepub fn total_header_size(&self) -> usize
pub fn total_header_size(&self) -> usize
Returns the total header size (mandatory 2 bytes + length bytes).