pub struct SequenceCount(/* private fields */);Expand description
The 14-bit packet sequence count.
A rolling counter for packets with a specific APID. This allows the receiver to detect dropped or out-of-order packets. The count wraps around from 16383 to 0.
Implementations
Sourceimpl SequenceCount
impl SequenceCount