pub enum TelecommandError {
BufferTooSmall {
required_len: usize,
provided_len: usize,
},
SpacePacketBuildError(BuildError),
SpacePacketParseError(ParseError),
MissingSecondaryHeader,
PayloadMismatch,
TypeMismatch,
}Expand description
An error that can occur when building a CFE packet.
Variants
BufferTooSmall
The provided buffer is too small to hold the packet.
Fields
SpacePacketBuildError(BuildError)
The underlying SPP builder returned an error.
SpacePacketParseError(ParseError)
The underlying SPP parser returned an error.
MissingSecondaryHeader
The secondary header flag is not set to Present.
PayloadMismatch
The packet data field does not match the expected layout.
TypeMismatch
The packet type does not match (e.g. telemetry instead of telecommand).