GossipMessageError

Enum GossipMessageError 

pub enum GossipMessageError {
    Cfe(TelecommandError),
    PayloadTooSmall,
    PayloadTooLarge {
        max: usize,
        provided: usize,
    },
}
An error that can occur when building or parsing a Gossip message.

Variants



Cfe(TelecommandError)

An error from the underlying CFE telecommand layer.



PayloadTooSmall

The payload is too small to contain a gossip header.



PayloadTooLarge

The payload exceeds the maximum allowed size.

Fields

max: usize

Maximum allowed payload size.

provided: usize

Actual payload size provided.