pub struct IslGossipHeader { /* private fields */ }Expand description
The ISL-specific header for a gossip message.
Implementations
Sourceimpl IslGossipHeader
impl IslGossipHeader
Sourcepub fn set_origin(&mut self, addr: Address)
pub fn set_origin(&mut self, addr: Address)
Sets the origin address in the gossip header.
Sourcepub fn predecessor(&self) -> Address
pub fn predecessor(&self) -> Address
Address of the immediate sender (for routing — don’t echo back).
Sourcepub fn set_predecessor(&mut self, addr: Address)
pub fn set_predecessor(&mut self, addr: Address)
Sets the from address in the gossip header.
Sourcepub fn epoch(&self) -> Epoch
pub fn epoch(&self) -> Epoch
The unique sequence number for this piece of gossip, used for duplicate detection.
Sourcepub fn service_area_min(&self) -> u8
pub fn service_area_min(&self) -> u8
The maximum service area (in hops) for this gossip. Nodes with a service area greater than this value should not forward the gossip further.
Sourcepub fn set_service_area_min(&mut self, area: u8)
pub fn set_service_area_min(&mut self, area: u8)
Sets the minimum service area in the gossip header.
Sourcepub fn service_area_max(&self) -> u8
pub fn service_area_max(&self) -> u8
The maximum service area (in hops) for this gossip. Nodes with a service area greater than this value should not forward the gossip further.
Sourcepub fn set_service_area_max(&mut self, area: u8)
pub fn set_service_area_max(&mut self, area: u8)
Sets the maximum service area in the gossip header.