IslGossipTelecommand

Struct IslGossipTelecommand 

#[repr(C)]
pub struct IslGossipTelecommand { pub primary: PrimaryHeader, pub secondary: TelecommandSecondaryHeader, pub gossip_header: IslGossipHeader, pub payload: [u8], }
A zero-copy view over a complete GossipTelecommand in a raw byte buffer.

This is a specialized Telecommand where the payload contains a GossipHeader that provides information for duplicate detection (epoch) and sender identification, followed by the actual data being gossiped.

+---------------------------------+-----------+
| Field Name                      | Size      |
+---------------------------------+-----------+
+ -- cFE Telecommand Hdrs ------- | --------- |
|                                 |           |
| Primary Header                  | 6 bytes   |
| Secondary Header                | 2 bytes   |
|                                 |           |
+ -- Gossip Header -------------- | --------- |
|                                 |           |
| Origin Address                  | 2 bytes   |
| From Address                    | 2 bytes   |
| Service Area Min                | 1 byte    |
| Service Area Max                | 1 byte    |
| Epoch                           | 2 bytes   |
| Action Code                     | 1 byte    |
|                                 |           |
| -- Gossip Payload (Variable) -- | --------- |
|                                 |           |
| Data being Gossiped             | 0-65524 B |
+---------------------------------+-----------+

Fields

primary: PrimaryHeader

CCSDS SPP primary header.

secondary: TelecommandSecondaryHeader

CFE command secondary header.

gossip_header: IslGossipHeader

ISL-specific gossip header.

payload: [u8]

Variable-length gossip data payload.

Implementations

Source

impl IslGossipTelecommand

pub fn from_telecommand(tc: &Telecommand) -> Result<&Self, GossipMessageError>

Safely parses a generic Telecommand as a GossipTelecommand.

pub fn set_cfe_checksum(&mut self)

Calculates and sets the 8-bit cFE checksum for this gossip packet.

pub fn validate_cfe_checksum(&self) -> bool

Returns true if the cFE checksum is valid.

pub fn data_len(&self) -> usize

Returns the length of the gossip data payload in bytes.

pub fn builder<'a>() -> IslGossipTelecommandBuilder<'a>

Builder for creating a complete ISL Gossip message.