IslMessageError

Enum IslMessageError 

pub enum IslMessageError {
    Cfe(TelecommandError),
    PayloadTooSmall,
    PayloadTooLarge {
        max: usize,
        provided: usize,
    },
}
An error that can occur when building or parsing an ISL message.

Variants



Cfe(TelecommandError)

An error occurred during the underlying CFE Telecommand construction.



PayloadTooSmall

A received packet was expected to be an ISL message but its payload was too small to contain a valid IslHeader.



PayloadTooLarge

The payload exceeds the maximum allowed size.

Fields

max: usize

Maximum allowed payload size.

provided: usize

Actual payload size provided.