Torus

Struct Torus 

pub struct Torus {
    pub num_orbs: u8,
    pub num_sats: u8,
}
A 2D toroidal grid.

Fields

num_orbs: u8

Number of orbital planes.

num_sats: u8

Number of satellites per orbital plane.

Implementations

Source

impl Torus

pub const fn new(num_orbs: u8, num_sats: u8) -> Self

Creates a new torus with the given dimensions.

pub fn neighbor(&self, point: Point, direction: Direction) -> Point

Calculates the position of a neighbor in a given direction from a starting point.

pub fn next(index: u8, modulus: u8) -> u8

Returns the next index, wrapping around at modulus.

pub fn prev(index: u8, modulus: u8) -> u8

Returns the previous index, wrapping around at modulus.

pub fn distance(from: u8, to: u8, modulus: u8) -> u8

Returns the forward distance from from to to on a circular axis.

pub fn next_sat(&self, p: Point) -> u8

Returns the satellite index after p.sat, wrapping around.

pub fn prev_sat(&self, p: Point) -> u8

Returns the satellite index before p.sat, wrapping around.

pub fn next_orb(&self, p: Point) -> u8

Returns the orbital plane index after p.orb, wrapping around.

pub fn prev_orb(&self, p: Point) -> u8

Returns the orbital plane index before p.orb, wrapping around.

pub fn distance_orb(&self, from: Point, to: Point) -> u8

Returns the distance between two orbits.

pub fn distance_sat(&self, from: Point, to: Point) -> u8

Returns the distance between two satellites.

pub fn direction_to_sat(&self, from: Point, to: Point) -> Direction

Returns the direction to move from from to to along the satellite axis.

pub fn direction_to_orb(&self, from: Point, to: Point) -> Direction

Returns the direction to move from from to to along the orbital plane axis.