ReceiverMachine

Struct ReceiverMachine 

pub struct ReceiverMachine { /* private fields */ }
Manages the state of all active receiving (‘destination’) transactions.

This struct holds a map of all transactions for which this entity is the receiver. It should be driven by a Runner which feeds it events and executes the resulting actions.

Implementations

Source

impl ReceiverMachine

pub fn new(id: EntityId) -> Self

Creates a new ReceiverMachine.

pub fn handle<'a>( &mut self, file_store: &mut impl FileStore, event: Event<'a>, actions: &mut Actions<'a>, ) -> Result<(), CfdpError>

The primary state machine logic for the receiver.

It takes an Event as input and returns a Vec of Actions for the Runner to execute. This function is pure and has no side effects.