TransactionState

Enum TransactionState 

pub enum TransactionState {
    ReceivingFileData,
    WaitingForNakData,
    VerifyingChecksum,
    WaitingForFilestoreResponses,
}
The lifecycle state of a receiving transaction.

Variants



ReceivingFileData

The receiver is actively receiving FileData PDUs.



WaitingForNakData

The receiver has received the EOF PDU but has missing data, and is waiting for retransmissions.



VerifyingChecksum

The receiver has a complete file and is waiting for the Runner to verify the checksum.



WaitingForFilestoreResponses

The receiver is waiting for the runner to execute filestore requests.