Transaction

Struct Transaction 

pub struct Transaction {
    pub tracker: SegmentTracker,
    pub config: TransactionConfig,
    pub filestore_requests: Vec<FilestoreRequest, 4, u8>,
    pub progress: u64,
    pub nak_timeout_secs: u16,
    pub keep_alive_interval_secs: u16,
    pub state: TransactionState,
    pub nak_retries: u8,
    pub nak_limit: u8,
    pub suspended: bool,
}
Holds all the dynamic and static state for a single, ongoing receiving transaction.

Fields

tracker: SegmentTracker

The data structure used to track missing file segments.

config: TransactionConfig

The shared, static configuration for this transaction.

filestore_requests: Vec<FilestoreRequest, 4, u8>

Filestore requests to be processed by the Runner.

progress: u64

The number of bytes of the file that have been successfully received and written.

nak_timeout_secs: u16

Timeout in seconds to wait for missing data after sending a NAK.

keep_alive_interval_secs: u16

The interval at which to send periodic KeepAlive PDUs.

state: TransactionState

The current position in the receiver’s lifecycle.

nak_retries: u8

A counter for the number of times a NAK sequence has been retransmitted.

nak_limit: u8

The number of times to retry sending a NAK sequence before faulting.

suspended: bool

Whether the transaction is currently suspended.