pub struct SenderMachine { /* private fields */ }Expand description
Manages the state of all active sending (‘source’) transactions.
This struct holds a map of all transactions for which this entity is the sender.
It should be driven by a Runner which feeds it events and executes the
resulting actions.
Implementations