Transaction

Struct Transaction 

pub struct Transaction {
    pub config: TransactionConfig,
    pub progress: u64,
    pub last_receiver_progress: u64,
    pub keep_alive_limit: u64,
    pub file_checksum: Option<u32>,
    pub ack_limit: u8,
    pub state: TransactionState,
    pub suspended: bool,
    pub ack_retries: u8,
}
Holds all the dynamic and static state for a single, ongoing sending transaction.

Fields

config: TransactionConfig

The shared, static configuration for this transaction.

progress: u64

The number of bytes of the file that have been successfully sent.

last_receiver_progress: u64

The last known progress of the receiver, as reported by KeepAlive PDUs.

keep_alive_limit: u64

The byte discrepancy limit for Keep Alive checks.

file_checksum: Option<u32>

The calculated checksum of the source file. Some once calculated.

ack_limit: u8

The number of times to retry sending an EOF before faulting.

state: TransactionState

The current position in the sender’s lifecycle.

suspended: bool

Whether the transaction is currently suspended.

ack_retries: u8

A counter for the number of times an EOF PDU has been retransmitted.