TransactionConfig

Struct TransactionConfig 

pub struct TransactionConfig {
    pub transaction_id: TransactionId,
    pub destination_id: EntityId,
    pub file_size: u64,
    pub fault_handlers: FaultHandlerSet,
    pub inactivity_timeout_secs: u16,
    pub checksum_type: ChecksumType,
    pub source_file_id: FileId,
    pub destination_file_id: FileId,
}
The static configuration for a single transaction that is shared between both sender and receiver.

This information is typically derived from the initial PutRequest (for the sender) or the received Metadata PDU (for the receiver).

Fields

transaction_id: TransactionId

The unique identifier for this transaction.

destination_id: EntityId

The EntityId of the destination for this transaction.

file_size: u64

The total size of the file in bytes.

fault_handlers: FaultHandlerSet

Optional fault handler overrides, one for each possible Condition Code. If an entry is None, the default MIB handler is used.

inactivity_timeout_secs: u16

Timeout in seconds to wait for any PDU before declaring the transaction inactive.

checksum_type: ChecksumType

The type of checksum to use for data integrity verification.

source_file_id: FileId

The name of the file at the source entity.

destination_file_id: FileId

The name the file should have at the destination entity.