FileDataPduWithoutMeta

Struct FileDataPduWithoutMeta 

pub struct FileDataPduWithoutMeta { /* private fields */ }
A zero-copy representation of the data field of a File Data PDU that does not have segment metadata.

It consists of a rest slice containing the FSS Offset and the file_data.

+------------------------------------+----------------+--------------------------------------+
| Field Name                         | Size           | Notes                                |
+------------------------------------+----------------+--------------------------------------+
| -- Start of PDU Data Field ------- | -------------- | ------------------------------------ |
| Offset                             | 32 or 64 bits  | FSS field. Byte offset into the file.|
|                                    | (FSS)          | Size depends on PDU Header's         |
|                                    |                | `Large File Flag`.                   |
| File data                          | Variable       | A chunk of the file's content.       |
+------------------------------------+----------------+--------------------------------------+

Implementations

Source

impl FileDataPduWithoutMeta

pub fn offset(&self, large_file_flag: bool) -> Result<u64, CfdpError>

Parses the FSS Offset from the start of the rest slice.

pub fn set_offset( &mut self, offset: u64, large_file_flag: bool, ) -> Result<(), CfdpError>

Sets the FSS byte offset into the file.

pub fn file_data(&self, large_file_flag: bool) -> Result<&[u8], CfdpError>

Returns the slice containing the actual file data.

pub fn file_data_mut( &mut self, large_file_flag: bool, ) -> Result<&mut [u8], CfdpError>

Returns a mutable slice containing the actual file data.

pub fn rest(&self) -> &[u8]

Get the raw rest field as a byte slice.

Source

impl FileDataPduWithoutMeta

pub fn builder<'a>() -> FileDataPduWithoutMetaBuilder<'a>

Builds a complete File Data PDU (without metadata). The caller is responsible for writing the file data into the buffer after this function returns.