pub struct AckPdu { /* private fields */ }Expand description
A zero-copy representation of the data field of an Acknowledgment (ACK) PDU.
This struct’s layout strictly follows the CCSDS specification (Table 5-8). It consists entirely of fixed-size fields, with several values bit-packed across two octets.
+------------------------------------+----------+--------------------------------------+
| Field Name | Size | Notes |
+------------------------------------+----------+--------------------------------------+
| Directive code of acked PDU | 4 bits | e.g., 0x04 for EOF, 0x05 for Fin. |
| Directive subtype code | 4 bits | (Both are packed into one octet) |
| | | |
| Condition code | 4 bits | Condition code of the acked PDU. |
| Reserved for future use | 2 bits | |
| Transaction status | 2 bits | (All three are packed into one octet)|
+------------------------------------+----------+--------------------------------------+Implementations
Sourceimpl AckPdu
impl AckPdu
Sourcepub fn acked_directive_code(&self) -> Result<AckedDirectiveCode, CfdpError>
pub fn acked_directive_code(&self) -> Result<AckedDirectiveCode, CfdpError>
Interprets the packed codes to determine what specific PDU is being acknowledged.
Sourcepub fn condition_code(&self) -> Result<ConditionCode, CfdpError>
pub fn condition_code(&self) -> Result<ConditionCode, CfdpError>
Returns the condition code of the PDU that is being acknowledged.
Sourcepub fn set_condition_code(&mut self, code: ConditionCode)
pub fn set_condition_code(&mut self, code: ConditionCode)
Sets the condition code of the acknowledged PDU.
Sourcepub fn transaction_status(&self) -> Result<TransactionStatus, CfdpError>
pub fn transaction_status(&self) -> Result<TransactionStatus, CfdpError>
Returns the status of the transaction at the acknowledging entity.
Sourcepub fn set_transaction_status(&mut self, status: TransactionStatus)
pub fn set_transaction_status(&mut self, status: TransactionStatus)
Sets the transaction status field.