ConditionCode

Enum ConditionCode 

#[repr(u8)]
pub enum ConditionCode {
Show 14 variants NoError = 0, AckLimitReached = 1, KeepAliveLimitReached = 2, InvalidTransmissionMode = 3, FilestoreRejection = 4, FileChecksumFailure = 5, FileSizeError = 6, NakLimitReached = 7, InactivityDetected = 8, InvalidFileStructure = 9, CheckLimitReached = 10, UnsupportedChecksumType = 11, SuspendReceived = 14, CancelReceived = 15,
}
Represents the Condition Code reported in EOF, Finished, and ACK PDUs.

Variants



NoError = 0

No error was detected.



AckLimitReached = 1

The acknowledgment limit was reached without receiving an expected ACK.



KeepAliveLimitReached = 2

The keep-alive limit was reached without receiving any PDU for the transaction.



InvalidTransmissionMode = 3

An invalid transmission mode was specified.



FilestoreRejection = 4

The filestore operation was rejected by the receiver.



FileChecksumFailure = 5

The file checksum did not match the expected value.



FileSizeError = 6

The file size did not match the expected value.



NakLimitReached = 7

The NAK limit was reached without satisfying all missing data requests.



InactivityDetected = 8

An inactivity timer expired.



InvalidFileStructure = 9

Invalid file structure.



CheckLimitReached = 10

The check limit was reached.



UnsupportedChecksumType = 11

The requested checksum type is not supported.



SuspendReceived = 14

A SUSPEND request was received for the transaction.



CancelReceived = 15

A CANCEL request was received for the transaction.