EofPdu

Struct EofPdu 

pub struct EofPdu { /* private fields */ }
A zero-copy representation of the data field of an End-of-File (EOF) PDU.

This struct’s layout strictly follows the CCSDS specification (Table 5-6). It consists of a fixed-size portion and a rest slice. The rest slice contains the File-Size Sensitive (FSS) file_size field and any optional Fault Location TLV.

+------------------------------------+----------------+--------------------------------------+
| Field Name                         | Size           | Notes                                |
+------------------------------------+----------------+--------------------------------------+
| Condition Code                     | 4 bits         | The reason for the end of file.      |
| Reserved for future use            | 4 bits         | Reserved, set to zero.               |
|                                    |                | (Both are packed into one octet)     |
|                                    |                |                                      |
| File Checksum                      | 32 bits        | Checksum of the entire file's data.  |
|                                    |                |                                      |
| -- Start of `rest` slice --------- | -------------- | ------------------------------------ |
| File Size                          | 32 or 64 bits  | FSS field. Size depends on header's  |
|                                    | (FSS)          | `Large File Flag`.                   |
|                                    |                |                                      |
| Fault Location (Optional)          | Variable (TLV) | Present if Condition Code is an error|
+------------------------------------+----------------+--------------------------------------+

Implementations

Source

impl EofPdu

pub fn condition_code(&self) -> Result<ConditionCode, CfdpError>

Returns the Condition Code (Table 5-5) from the bit-packed field.

pub fn set_condition_code(&mut self, code: ConditionCode)

Sets the condition code field.

pub fn file_checksum(&self) -> u32

Returns the 32-bit file checksum.

pub fn set_file_checksum(&mut self, checksum: u32)

Sets the 32-bit file checksum.

pub fn file_size(&self, large_file_flag: bool) -> Result<u64, CfdpError>

Correctly parses the File-Size Sensitive (FSS) file_size field from the rest slice.

Arguments
  • large_file_flag: The state of the Large File Flag from the PDU header, which determines whether to parse 32 or 64 bits.
pub fn set_file_size( &mut self, large_file_flag: bool, file_size: u64, ) -> Result<(), CfdpError>

Sets the FSS file size field.

pub fn tlvs(&self, large_file_flag: bool) -> Result<TlvIterator<'_>, CfdpError>

Returns an iterator over any trailing TLVs (e.g., Fault Location).

pub fn fault_location( &self, large_file_flag: bool, ) -> Result<Option<&Tlv>, CfdpError>

Finds and returns the Fault Location TLV’s value from the data field.

The Fault Location is an Entity ID, as defined by the standard. This method will search for the first TLV with the correct type.

pub fn rest(&self) -> &[u8]

Get the raw rest field as a byte slice.

Source

impl EofPdu

pub fn builder<'a>() -> EofPduBuilder<'a>

Builds a new EOF PDU in the given buffer.