pub struct MetadataPdu { /* private fields */ }Expand description
A zero-copy representation of the data field of a Metadata PDU.
This struct’s layout strictly follows the CCSDS specification (Table 5-9).
It consists of a fixed-size portion and a rest slice. The rest slice
contains the LV-encoded file names and any optional TLVs.
+------------------------------------+----------------+--------------------------------------+
| Field Name | Size | Notes |
+------------------------------------+----------------+--------------------------------------+
| Reserved for future use | 1 bit | |
| Closure requested | 1 bit | |
| Reserved for future use | 2 bit | |
| Checksum type | 4 bits | (Packed into one octet with spares) |
| | | |
| File Size | 32 or 64 bits | FSS field. |
| | (FSS) | |
| -- Start of `rest` slice --------- | -------------- | ------------------------------------ |
| Source File Name | Variable (LV) | Length-Value encoded. |
| Destination File Name | Variable (LV) | Length-Value encoded. |
| Options (Optional) | Variable (TLV) | Zero or more TLVs. |
+------------------------------------+----------------+--------------------------------------+Implementations
Sourceimpl MetadataPdu
impl MetadataPdu
Sourcepub fn closure_requested(&self) -> bool
pub fn closure_requested(&self) -> bool
Returns the state of the Closure requested flag.
Sourcepub fn set_closure_requested(&mut self, requested: bool)
pub fn set_closure_requested(&mut self, requested: bool)
Sets the Closure requested flag.
Sourcepub fn checksum_type(&self) -> Result<ChecksumType, CfdpError>
pub fn checksum_type(&self) -> Result<ChecksumType, CfdpError>
Returns the 4-bit integer identifying the checksum algorithm to be used.
Sourcepub fn set_checksum_type(&mut self, checksum_type: ChecksumType)
pub fn set_checksum_type(&mut self, checksum_type: ChecksumType)
Sets the checksum type field.
Sourcepub fn file_size(&self, large_file_flag: bool) -> Result<u64, CfdpError>
pub fn file_size(&self, large_file_flag: bool) -> Result<u64, CfdpError>
Correctly parses the File-Size Sensitive (FSS) file_size field.
Sourcepub fn set_file_size(
&mut self,
large_file_flag: bool,
file_size: u64,
) -> Result<(), CfdpError>
pub fn set_file_size( &mut self, large_file_flag: bool, file_size: u64, ) -> Result<(), CfdpError>
Sets the FSS file size field.
Sourcepub fn variable_fields(
&self,
large_file_flag: bool,
) -> Result<(&[u8], &[u8], TlvIterator<'_>), CfdpError>
pub fn variable_fields( &self, large_file_flag: bool, ) -> Result<(&[u8], &[u8], TlvIterator<'_>), CfdpError>
A private helper to parse the variable-length fields after the FSS file_size. This avoids re-parsing the LV fields in each public getter. Returns (source_name, dest_name, options_slice)
Sourcepub fn set_variable_fields(
&mut self,
large_file_flag: bool,
source_file_name: &[u8],
dest_file_name: &[u8],
options: Option<&[u8]>,
) -> Result<(), CfdpError>
pub fn set_variable_fields( &mut self, large_file_flag: bool, source_file_name: &[u8], dest_file_name: &[u8], options: Option<&[u8]>, ) -> Result<(), CfdpError>
Writes the LV-encoded file names and optional TLV options into the PDU.
Sourcepub fn source_file_name(
&self,
large_file_flag: bool,
) -> Result<&[u8], CfdpError>
pub fn source_file_name( &self, large_file_flag: bool, ) -> Result<&[u8], CfdpError>
Returns a slice representing the source file name.
Sourcepub fn dest_file_name(&self, large_file_flag: bool) -> Result<&[u8], CfdpError>
pub fn dest_file_name(&self, large_file_flag: bool) -> Result<&[u8], CfdpError>
Returns a slice representing the destination file name.
Sourcepub fn options(
&self,
large_file_flag: bool,
) -> Result<TlvIterator<'_>, CfdpError>
pub fn options( &self, large_file_flag: bool, ) -> Result<TlvIterator<'_>, CfdpError>
Returns an iterator over the TLV options in the metadata.
Sourcepub fn fault_handler_overrides(
&self,
large_file_flag: bool,
) -> Result<FaultHandlerSet, CfdpError>
pub fn fault_handler_overrides( &self, large_file_flag: bool, ) -> Result<FaultHandlerSet, CfdpError>
Parses the Fault Handler Override TLVs and returns a FaultHandlerSet.
The set is initialized with default handlers, which are then updated
by any overrides present in the PDU’s options.
Sourceimpl MetadataPdu
impl MetadataPdu
Sourcepub fn builder<'a>() -> MetadataPduBuilder<'a>
pub fn builder<'a>() -> MetadataPduBuilder<'a>
Builds a new Metadata PDU in the given buffer.