pub struct NakPduLarge { /* private fields */ }Expand description
A zero-copy representation of the data field of a NAK PDU for large files.
+------------------------------------+-----------+--------------------------------------+
| Field Name | Size | Notes |
+------------------------------------+-----------+--------------------------------------+
| Start of scope | 64 bits | FSS field. |
| End of scope | 64 bits | FSS field. |
| -- Start of `rest` slice --------- | --------- | ------------------------------------ |
| Segment Requests | Variable | Zero or more `NakSegmentSmall`s. |
+------------------------------------+-----------+--------------------------------------+Implementations
Sourceimpl NakPduLarge
impl NakPduLarge
Sourcepub fn segment_requests(&self) -> Result<&[NakSegmentLarge], CfdpError>
pub fn segment_requests(&self) -> Result<&[NakSegmentLarge], CfdpError>
Parses the rest slice into a slice of NakSegmentLarges.
Sourcepub fn start_of_scope(&self) -> u64
pub fn start_of_scope(&self) -> u64
Get the start_of_scope field as a u64.
Sourcepub fn set_start_of_scope(&mut self, scope: u64)
pub fn set_start_of_scope(&mut self, scope: u64)
Sets the start of scope field.
Sourcepub fn end_of_scope(&self) -> u64
pub fn end_of_scope(&self) -> u64
Get the end_of_scope field as a u64.
Sourcepub fn set_end_of_scope(&mut self, scope: u64)
pub fn set_end_of_scope(&mut self, scope: u64)
Sets the end of scope field.
Sourceimpl NakPduLarge
impl NakPduLarge
Sourcepub fn builder<'a>() -> NakPduLargeBuilder<'a>
pub fn builder<'a>() -> NakPduLargeBuilder<'a>
Builds a new large-file NAK PDU in the given buffer.