pub struct PromptPdu { /* private fields */ }Expand description
A zero-copy representation of the data field of a Prompt PDU.
This struct’s layout strictly follows the CCSDS specification (Table 5-12). It has a fixed size of 2 bytes.
+------------------------------------+----------+------------------------------------+
| Field Name | Size | Notes |
+------------------------------------+----------+------------------------------------+
| Response required | 1 bit | 0=NAK, 1=Keep Alive |
| Spare | 7 bits | (Both are packed into one octet) |
+------------------------------------+----------+------------------------------------+Implementations
Sourceimpl PromptPdu
impl PromptPdu
Sourcepub fn prompt_response(&self) -> PromptResponse
pub fn prompt_response(&self) -> PromptResponse
Returns whether a response is required for this Prompt PDU.
Sourcepub fn set_prompt_response(&mut self, response: PromptResponse)
pub fn set_prompt_response(&mut self, response: PromptResponse)
Sets the response type for this Prompt PDU.