FileDirectivePdu

Struct FileDirectivePdu 

pub struct FileDirectivePdu { /* private fields */ }
A zero-copy representation of the start of any File Directive’s data field. It provides the directive code, which can then be used to parse the rest of the data field into a more specific PDU type (EofPdu, FinishedPdu, etc.).

+------------------------------------+----------------+
| Field Name                         | Size           |
+------------------------------------+----------------+
| Directive Code                     | 8 bits         |
| `rest` (contents depend on code)   | Variable       |
+------------------------------------+----------------+

Implementations

Source

impl FileDirectivePdu

pub fn directive_code(&self) -> Result<DirectiveCode, CfdpError>

Returns the DirectiveCode enum variant for this PDU.

pub fn set_directive_code(&mut self, code: DirectiveCode)

Sets the directive code for this PDU.

pub fn rest(&self) -> &[u8]

Get the raw rest field as a byte slice.