Pdu

Struct Pdu 

pub struct Pdu { /* private fields */ }
A zero-copy view of a generic CFDP PDU, containing the header and raw bytes.

+—————————————+—————+ | Field Name | Size | +—————————————+—————+ | – PDU Header (Variable Length) —– | ———–– | | | | | – Fixed Part (4 bytes) ———–– | ———–– | | | | | Version Number | 3 bits | | PDU Type | 1 bit | | Direction | 1 bit | | Transmission Mode | 1 bit | | CRC Flag | 1 bit | | Large File Flag | 1 bit | | | | | PDU Data Field Length | 16 bits | | | | | Segmentation Control | 1 bit | | Length of Entity IDs | 3 bits | | Segment Metadata Flag | 1 bit | | Length of Transaction Sequence Number | 3 bits | | | | | – Variable Part (3 to 24 bytes) –– | ———–– | | | | | Source Entity ID | 1 to 8 octets | | Transaction Sequence Number | 1 to 8 octets | | Destination Entity ID | 1 to 8 octets | | | | +—————————————+—————+ | – PDU Data Field (Variable Length) - | ———–– | | | | +—————————————+—————+

Implementations

Source

impl Pdu

pub fn header(&self) -> &PduHeaderFixedPart

Returns the fixed part of the header.

pub fn header_mut(&mut self) -> &mut PduHeaderFixedPart

Returns a mutable reference to the fixed part of the header.

pub fn variant(&self) -> Result<PduVariant<'_>, CfdpError>

Parses the PDU data field into a typed PduVariant.

pub fn set_header(&mut self, header: PduHeaderFixedPart)

Sets the fixed part of the header.

pub fn rest(&self) -> &[u8]

Returns the raw rest field as a byte slice.

pub fn header_len(&self) -> usize

Returns the total length of the PDU header (fixed + variable parts).

pub fn source_entity_id(&self) -> Result<EntityId, CfdpError>

Parses and returns a slice for the source entity ID.

pub fn set_source_entity_id( &mut self, source_entity_id: EntityId, ) -> Result<(), CfdpError>

Writes the source entity ID into the variable header.

pub fn transaction_seq_num(&self) -> Result<TransactionSeqNum, CfdpError>

Parses and returns a slice for the transaction sequence number.

pub fn set_transaction_seq_num( &mut self, txn_seq_num: TransactionSeqNum, ) -> Result<(), CfdpError>

Writes the transaction sequence number into the variable header.

pub fn set_destination_entity_id( &mut self, dest_entity_id: EntityId, ) -> Result<(), CfdpError>

Parses and returns a slice for the destination entity ID.

pub fn data_field(&self) -> Result<&[u8], CfdpError>

Returns a slice representing the PDU’s data field.

pub fn data_field_mut(&mut self) -> Result<&mut [u8], CfdpError>

Returns a mutable slice representing the PDU’s data field.

pub fn from_bytes(buffer: &[u8]) -> Result<&Pdu, CfdpError>

A convenience method to parse the entire PDU from a byte buffer.

pub fn from_bytes_mut(buffer: &mut [u8]) -> Result<&mut Pdu, CfdpError>

A convenience method to parse the entire PDU from a byte buffer.

Source

impl Pdu

pub fn builder<'a>() -> PduBuilder<'a>

Builds a new PDU in the given buffer with header and entity IDs.

Methods from Deref<Target = PduHeaderFixedPart>

pub fn version(&self) -> u8

Returns the 3-bit CFDP version number.

pub fn set_version(&mut self, version: u8)

Sets the 3-bit CFDP version number.

pub fn pdu_type(&self) -> PduType

Returns the PDU type (File Data or File Directive).

pub fn set_pdu_type(&mut self, pdu_type: PduType)

Sets the PDU type field.

pub fn direction(&self) -> Direction

Returns the direction of the PDU.

pub fn set_direction(&mut self, direction: Direction)

Sets the direction field.

pub fn tx_mode(&self) -> TransmissionMode

Returns the transmission mode (Acknowledged or Unacknowledged).

pub fn set_tx_mode(&mut self, tx_mode: TransmissionMode)

Sets the transmission mode field.

pub fn crc_flag(&self) -> bool

Returns true if the PDU includes a CRC.

pub fn set_crc_flag(&mut self, crc_flag: bool)

Sets the CRC flag.

pub fn large_file_flag(&self) -> bool

Returns true if this is a large-file transaction (64-bit offsets).

pub fn set_large_file_flag(&mut self, large_file_flag: bool)

Sets the large file flag.

pub fn data_field_len(&self) -> usize

Returns the length of the PDU data field in bytes.

pub fn set_data_field_len(&mut self, len: u16)

Sets the PDU data field length.

pub fn segmentation_control(&self) -> bool

Returns the segmentation control flag.

pub fn set_segmentation_control(&mut self, seg_ctrl: bool)

Sets the segmentation control flag.

pub fn entity_id_len(&self) -> usize

Returns the length of entity IDs in bytes (1 to 8).

pub fn set_entity_id_len(&mut self, len: usize) -> Result<(), CfdpError>

Sets the entity ID length (must be 1 to 8).

pub fn segment_metadata_flag(&self) -> bool

Returns the segment metadata flag.

pub fn set_segment_metadata_flag(&mut self, seg_meta_flag: bool)

Sets the segment metadata flag.

pub fn txn_seq_num_len(&self) -> usize

Returns the length of the transaction sequence number in bytes.

pub fn set_txn_seq_num_len(&mut self, len: usize) -> Result<(), CfdpError>

Sets the transaction sequence number length (must be 1 to 8).

pub fn fixed_header_len(&self) -> usize

Returns the size of the fixed header portion in bytes.

pub fn variable_header_len(&self) -> usize

Calculates the length of the variable-sized portion of the PDU header

pub fn total_header_len(&self) -> usize

Returns the total header length (fixed + variable parts).

pub fn total_pdu_len(&self) -> usize

Returns the total PDU length (header + data field).