FaultHandlerSet

Struct FaultHandlerSet 

pub struct FaultHandlerSet(/* private fields */);
A bit-packed structure to store the fault handler action for all 16 possible CFDP condition codes in a single u32.

Each handler requires 2 bits to represent the 4 possible actions. 16 conditions * 2 bits/condition = 32 bits.

Implementations

Source

impl FaultHandlerSet

pub fn new(default_handler: HandlerCode) -> Self

Creates a new FaultHandlerSet where all handlers are set to the specified default action.

pub fn set_handler(&mut self, condition: ConditionCode, handler: HandlerCode)

Sets the handler for a specific condition code.

pub fn get_handler(&self, condition: ConditionCode) -> HandlerCode

Gets the handler for a specific condition code.