SrsppTxHandle

Struct SrsppTxHandle 

pub struct SrsppTxHandle<'a, E, S: MessageStore, R: Reachable, const WIN: usize, const BUF: usize, const MTU: usize> { /* private fields */ }
Handle for sending data over an SRSPP node.

Implementations

Source

impl<'a, E: Clone, S: MessageStore, R: Reachable, const WIN: usize, const BUF: usize, const MTU: usize> SrsppTxHandle<'a, E, S, R, WIN, BUF, MTU>

pub async fn send( &mut self, target: impl Into<Address>, data: &(impl IntoBytes + Immutable + ?Sized), ) -> Result<(), TransportError<E>>

Sends data to the given target.

If the destination is unreachable, the message is stored for later delivery by the driver. If reachable, it enters SRSPP normally.

pub fn close(&mut self)

Signal that no more data will be sent. Driver will exit once all pending data is acknowledged and the store is drained.

pub fn available_bytes(&self) -> usize

Check available buffer space in bytes.

pub fn available_window(&self) -> usize

Check available window slots.

pub fn is_idle(&self) -> bool

Check if all data has been acknowledged.