pub struct AckState { /* private fields */ }Expand description
ACK and timer state, driven by DataOutcome/GapOutcome from a backend.
Implementations
Sourceimpl AckState
impl AckState
Sourcepub fn new(config: &ReceiverConfig, remote_address: Address) -> Self
pub fn new(config: &ReceiverConfig, remote_address: Address) -> Self
Create ACK state for a stream from receiver config and remote address.
Sourcepub fn on_ack_timeout(
&mut self,
seq: SequenceCount,
bitmap: u16,
) -> HandleResult
pub fn on_ack_timeout( &mut self, seq: SequenceCount, bitmap: u16, ) -> HandleResult
Handle delayed ACK timer expiry.
Sourcepub fn on_data(
&mut self,
outcome: DataOutcome,
seq: SequenceCount,
bitmap: u16,
) -> HandleResult
pub fn on_data( &mut self, outcome: DataOutcome, seq: SequenceCount, bitmap: u16, ) -> HandleResult
Produce ACK/timer actions after the backend processed a data packet.
Sourcepub fn on_gap_skip(&mut self, outcome: GapOutcome) -> HandleResult
pub fn on_gap_skip(&mut self, outcome: GapOutcome) -> HandleResult
Produce timer actions after the backend skipped a gap.