ContactSchedule

Struct ContactSchedule 

pub struct ContactSchedule<const N: usize> { /* private fields */ }
Ordered schedule of ground station contact windows.

Implementations

Source

impl<const N: usize> ContactSchedule<N>

pub fn new() -> Self

Create an empty contact schedule.

pub fn add_window(&mut self, window: ContactWindow) -> Result<(), ContactWindow>

Insert a contact window in chronological order.

pub fn in_window(&self, now_secs: u32) -> bool

Check if the given time falls within any contact window.

pub fn next_window(&self, now_secs: u32) -> Option<&ContactWindow>

Return the next contact window starting after the given time.