pub struct TelecommandTransferFrame { /* private fields */ }Expand description
A zero-copy view over a CCSDS Telecommand (TC) Transfer Frame in a raw byte buffer.
This struct represents the “envelope” used to send one or more SpacePackets
from the ground to a spacecraft (the uplink). It provides the necessary routing
(SCID, VCID) and sequencing for the radio link.
It is typically constructed via the ergonomic TelecommandTransferFrame::builder().
Layout
A TC Transfer Frame consists of a 5-byte header followed by a data field.
+------------------------------------+---------------------+
| Field Name | Size |
+------------------------------------+---------------------+
+ -- Transfer Frame Header (5 bytes) | |
| | |
| Transfer Frame Version | 2 bits |
| Bypass Flag | 1 bit |
| Control Command Flag | 1 bit |
| Reserved | 2 bits |
| Spacecraft ID (SCID) | 10 bits |
| Virtual Channel ID (VCID) | 6 bits |
| Frame Length | 10 bits |
| Frame Sequence Number | 8 bits |
| | |
+ -- Data Field -------------------- | 1 - 1019 bytes |
| | |
| Contains one or more Space Packets | |
+------------------------------------+---------------------+Implementations
Sourceimpl TelecommandTransferFrame
impl TelecommandTransferFrame
Sourcepub const HEADER_SIZE: usize = 5
pub const HEADER_SIZE: usize = 5
The size of the Telecommand Transfer Frame header in bytes.
Sourcepub const MAX_DATA_FIELD_LEN: usize = 1019
pub const MAX_DATA_FIELD_LEN: usize = 1019
The maximum allowed size of the data field in bytes.
Sourcepub fn parse(bytes: &[u8]) -> Result<&Self, ParseError>
pub fn parse(bytes: &[u8]) -> Result<&Self, ParseError>
Parses a raw byte slice into a zero-copy Telecommand Transfer Frame view.
Sourcepub fn header(&self) -> &TelecommandTransferFrameHeader
pub fn header(&self) -> &TelecommandTransferFrameHeader
Returns a reference to the frame’s header.
Sourcepub fn data_field_mut(&mut self) -> &mut [u8] ⓘ
pub fn data_field_mut(&mut self) -> &mut [u8] ⓘ
Returns a mutable reference to the frame’s data field.
Sourcepub fn data_field(&self) -> &[u8] ⓘ
pub fn data_field(&self) -> &[u8] ⓘ
Returns a reference to the frame’s data field.
Sourcepub fn frame_len(&self) -> usize
pub fn frame_len(&self) -> usize
Returns the total length of the frame (header + data field) in bytes.
Sourcepub fn builder<'f1>() -> TelecommandTransferFrameBuilder<'f1>
pub fn builder<'f1>() -> TelecommandTransferFrameBuilder<'f1>
Constructs a new TC Transfer Frame in the provided buffer.