pub struct FrameSecurityReport {
pub last_spi: u16,
pub arsn_lsb: u8,
pub alarm: bool,
pub bad_sn: bool,
pub bad_mac: bool,
pub bad_sa: bool,
}Expand description
Frame Security Report (FSR) — 32-bit OCF carried in TM/AOS/USLP frames to report security status (Section 4.2.2).
Fields
last_spi: u16Last SPI used by the receiving security function.
arsn_lsb: u88 LSBs of the ARSN from the last received frame.
alarm: boolAlarm flag: at least one frame was rejected since last reset.
bad_sn: boolBad Sequence Number flag for the last received frame.
bad_mac: boolBad MAC flag for the last received frame.
bad_sa: boolBad SA flag for the last received frame.
Implementations