pub enum DataFieldError {
SizeMismatch,
InvalidLayout,
SecondaryHeaderAbsent,
}Expand description
An error that occurs when setting or getting the typed data field.
Variants
SizeMismatch
The size of the provided data does not match the size of the packet’s data field.
InvalidLayout
The packet’s data field could not be safely cast to the target data type, often due to alignment issues or an invalid discriminant.
SecondaryHeaderAbsent
A secondary header was requested but the secondary header flag is absent.