pub trait SpacePacketData:
FromBytes
+ IntoBytes
+ KnownLayout
+ Unaligned
+ Immutable { }Expand description
A trait alias for the required bounds on a zero-copy packet data payload.
This is a convenience trait that bundles the necessary traits from the zerocopy
crate. Any struct that will be used as a typed data field should be able to
be soundly cast to and from a byte slice.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.