pub struct GeoAoi {
pub upper_left: LatLon,
pub lower_right: LatLon,
}Expand description
A geographic area of interest defined by its bounding box corners.
Fields
upper_left: LatLonUpper-left (northwest) corner of the bounding box.
lower_right: LatLonLower-right (southeast) corner of the bounding box.
Implementations
Sourceimpl GeoAoi
impl GeoAoi
Sourcepub fn new(upper_left: LatLon, lower_right: LatLon) -> Self
pub fn new(upper_left: LatLon, lower_right: LatLon) -> Self
Creates a new geographic AOI from its bounding box corners.
Sourcepub fn contains(&self, point: LatLon) -> bool
pub fn contains(&self, point: LatLon) -> bool
Returns true if the given point lies within this AOI.
Sourcepub fn height_deg(&self) -> f32
pub fn height_deg(&self) -> f32
Returns the latitudinal height in degrees.