pub struct FileDataPduWithoutMeta { /* private fields */ }Expand description
A zero-copy representation of the data field of a File Data PDU that does not have segment metadata.
It consists of a rest slice containing the FSS Offset and the file_data.
+------------------------------------+----------------+--------------------------------------+
| Field Name | Size | Notes |
+------------------------------------+----------------+--------------------------------------+
| -- Start of PDU Data Field ------- | -------------- | ------------------------------------ |
| Offset | 32 or 64 bits | FSS field. Byte offset into the file.|
| | (FSS) | Size depends on PDU Header's |
| | | `Large File Flag`. |
| File data | Variable | A chunk of the file's content. |
+------------------------------------+----------------+--------------------------------------+Implementations
Sourceimpl FileDataPduWithoutMeta
impl FileDataPduWithoutMeta
Sourcepub fn offset(&self, large_file_flag: bool) -> Result<u64, CfdpError>
pub fn offset(&self, large_file_flag: bool) -> Result<u64, CfdpError>
Parses the FSS Offset from the start of the rest slice.
Sourcepub fn set_offset(
&mut self,
offset: u64,
large_file_flag: bool,
) -> Result<(), CfdpError>
pub fn set_offset( &mut self, offset: u64, large_file_flag: bool, ) -> Result<(), CfdpError>
Sets the FSS byte offset into the file.
Sourcepub fn file_data(&self, large_file_flag: bool) -> Result<&[u8], CfdpError>
pub fn file_data(&self, large_file_flag: bool) -> Result<&[u8], CfdpError>
Returns the slice containing the actual file data.
Sourceimpl FileDataPduWithoutMeta
impl FileDataPduWithoutMeta
Sourcepub fn builder<'a>() -> FileDataPduWithoutMetaBuilder<'a>
pub fn builder<'a>() -> FileDataPduWithoutMetaBuilder<'a>
Builds a complete File Data PDU (without metadata). The caller is responsible for writing the file data into the buffer after this function returns.