pub struct ContactSchedule<const N: usize> { /* private fields */ }Expand description
Ordered schedule of ground station contact windows.
Implementations
Sourceimpl<const N: usize> ContactSchedule<N>
impl<const N: usize> ContactSchedule<N>
Sourcepub fn add_window(&mut self, window: ContactWindow) -> Result<(), ContactWindow>
pub fn add_window(&mut self, window: ContactWindow) -> Result<(), ContactWindow>
Insert a contact window in chronological order.
Sourcepub fn in_window(&self, now_secs: u32) -> bool
pub fn in_window(&self, now_secs: u32) -> bool
Check if the given time falls within any contact window.
Sourcepub fn next_window(&self, now_secs: u32) -> Option<&ContactWindow>
pub fn next_window(&self, now_secs: u32) -> Option<&ContactWindow>
Return the next contact window starting after the given time.